function [d,s]=lookup_QMOD4(azi,in1,sig)
% 
% for a given radar azimuth and incidence angle and sigma0 value,
% "lookup" the wind directions and speed that give rise to the same
% sigma0 values
%
%  [d,s]=lookup_QMOD4(azi,in1,sig)
%
% uses the global variable GMF previously loaded by load_QMOD4.m

% written 5 Jul 2005 by D.Long at BYU

global GMF
% The global variable GMF varies first in incidence angle, then in wind
% speed, then in relative azimuth. see load_QMOD4.m

if prod(size(GMF))==0 % load GMF if not already present
  load_QMOD4;
end

sigma0=zeros(size(azi));

% convert inputs to table indexes
s=spd*10;
u1=floor(s);
u2=u1+1;

in=in1-39;
inc=floor(in);
in=inc+1;

chi=azi-d; % relative wind direction
chi=mod(chi+360,360);

c1=floor(chi);
c2=c1+1;

% trilinearly interpolate GMF table to generate a value for sigma0
% (taking advantage of the single unit spacing of the table)
for i=1:length(prod(azi))
  sigma0(i)=(in(i)-inc(i))* ...
               ((chi(i) - c1(i))*(s(i)-u1(i)  )*GMF(inc(i),u1(i)+1,c1(i)+1)+...
		(1+c1(i)-chi(i))*(s(i)-u1(i)  )*GMF(inc(i),u1(i)+1,c2(i)+1)+...
		(chi(i) - c1(i))*(1+u1(i)-s(i))*GMF(inc(i),u2(i)+1,c1(i)+1)+...
		(1+c1(i)-chi(i))*(1+u1(i)-s(i))*GMF(inc(i),u2(i)+1,c2(i)+1))+...
	    (1+inc(i)-in(i))* ...
	       ((chi(i) - c1(i))*(s(i)-u1(i)  )*GMF(inc(i)+1,u1(i)+1,c1(i)+1)+...
		(1+c1(i)-chi(i))*(s(i)-u1(i)  )*GMF(inc(i)+1,u1(i)+1,c2(i)+1)+...
		(chi(i) - c1(i))*(1+u1(i)-s(i))*GMF(inc(i)+1,u2(i)+1,c1(i)+1)+...
		(1+c1(i)-chi(i))*(1+u1(i)-s(i))*GMF(inc(i)+1,u2(i)+1,c2(i)+1));
end
