function [dout,sout]=lookup_sigma0_QMOD4(azi,in1,sig)
% 
% for a given radar azimuth and incidence angle and sigma0 value (in
% normal space), "lookup" the wind directions and speed that give 
% rise to the same sigma0 values
%
%  [d,s]=lookup_sigma0_QMOD4(azi,inc,sig)
%   (azi, inc, sig should be singleton)
%
% uses the global variable GMF previously loaded by load_QMOD4.m

% written 5 Jul 2005 by D.Long at BYU

global GMF
% The global variable GMF varies first in incidence angle, then in wind
% speed, then in relative azimuth. see load_QMOD4.m

if prod(size(GMF))==0 % load GMF if not already present
  load_QMOD4;
end

dout=zeros(size(sig));
sout=zeros(size(sig));

% convert input incidence angle to table indices
in=in1-39;
inc=floor(in);
in=inc+1;

% Use a brute force search: for each direction, find corresponding wind
% speed that minimizes sigma-0 difference (which if we were doing exact
% interpolations, would be zero). This search takes advantage of the
% monotonic relation of sigma vs speed at a fix direction (and geometry)

for kdir=1:360
  wdir=(kdir-1);
  chi=azi-wdir; % relative wind direction
  chi=mod(chi+360,360);
  c1=floor(chi);
  c2=c1+1;
  c2(c2>361)=c2(c2>361)-361;

  sigs=zeros([501,1]);
  for kspd=1:500
    s=(kspd-1);
    u1=floor(s);
    u2=u1+1;

    i=1;
    % trilinearly interpolate GMF table to generate a value for sigma0
    % (taking advantage of the single unit spacing of the table)
    sigs(kspd)=(in(i)-inc(i))* ...
               ((chi(i) - c1(i))*(s(i)-u1(i)  )*GMF(inc(i),u1(i)+1,c1(i)+1)+...
		(1+c1(i)-chi(i))*(s(i)-u1(i)  )*GMF(inc(i),u1(i)+1,c2(i)+1)+...
		(chi(i) - c1(i))*(1+u1(i)-s(i))*GMF(inc(i),u2(i)+1,c1(i)+1)+...
		(1+c1(i)-chi(i))*(1+u1(i)-s(i))*GMF(inc(i),u2(i)+1,c2(i)+1))+...
	    (1+inc(i)-in(i))* ...
	       ((chi(i) - c1(i))*(s(i)-u1(i)  )*GMF(inc(i)+1,u1(i)+1,c1(i)+1)+...
		(1+c1(i)-chi(i))*(s(i)-u1(i)  )*GMF(inc(i)+1,u1(i)+1,c2(i)+1)+...
		(chi(i) - c1(i))*(1+u1(i)-s(i))*GMF(inc(i)+1,u2(i)+1,c1(i)+1)+...
		(1+c1(i)-chi(i))*(1+u1(i)-s(i))*GMF(inc(i)+1,u2(i)+1,c2(i)+1));
  end
  [mv ind]=min(abs(sigs-sig));
  
  % simple schemd to interpolate in wind speed
  k=(-2:2)+ind(1);
  k(k<1)=1;
  k(k>501)=501;
  xq=-2:0.1:2;
  V=interp1(-2:2,sigs(k),xq,'spline');
  [mv ind1]=min(abs(V-sig));
  
  dout(kdir)=wdir;
  sout(kdir)=(ind-1+xq(ind1))*0.1;  
end

%plot(dout,sout)